package de.intevation.flys.client.client.ui.chart;

import com.google.gwt.core.client.GWT;

import com.smartgwt.client.widgets.Button;
import com.smartgwt.client.widgets.Label;
import com.smartgwt.client.widgets.layout.HLayout;
import com.smartgwt.client.widgets.events.ClickEvent;
import com.smartgwt.client.widgets.events.ClickHandler;
import com.smartgwt.client.widgets.events.CloseClickHandler;
import com.smartgwt.client.widgets.events.CloseClientEvent;

import de.intevation.flys.client.shared.model.Artifact;

import de.intevation.flys.client.client.FLYSConstants;
import de.intevation.flys.client.client.ui.CollectionView;
import de.intevation.flys.client.client.ui.DatacageWindow;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ChartToolbar extends HLayout {

    protected static FLYSConstants MSG = GWT.create(FLYSConstants.class);


    public static final int PANEL_HEIGHT = 30;


    protected CollectionView view;

    protected ChartOutputTab chartTab;


    protected Button datacage;

    protected MousePositionPanel position;

    protected ZoomboxControl zoombox;



    public ChartToolbar(CollectionView view, ChartOutputTab chartTab) {
        super();

        this.view       = view;
        this.chartTab   = chartTab;

        datacage = new Button(MSG.databasket());
        position = new MousePositionPanel(chartTab);
        zoombox  = new ZoomboxControl(chartTab);

        datacage.addClickHandler(new ClickHandler() {
            public void onClick(ClickEvent event) {
                GWT.log("Clicked 'datacage' button.");
                openDatacageWindow(getArtifact());
            }
        });

        zoombox.addZoomHandler(chartTab);

        initLayout();
    }


    public Artifact getArtifact() {
        return view.getArtifact();
    }


    protected void initLayout() {
        setWidth100();
        setHeight(PANEL_HEIGHT);
        setMembersMargin(10);
        setPadding(5);
        setBorder("1px solid black");

        Label spacer = new Label();
        spacer.setWidth("*");
        datacage.setWidth("95px");
        position.setWidth("200px");

        addMember(datacage);
        addMember(zoombox);
        addMember(spacer);
        addMember(position);
    }


    protected void openDatacageWindow(Artifact artifact) {
        final DatacageWindow dc = new DatacageWindow(artifact);
        dc.addCloseClickHandler(new CloseClickHandler() {
            public void onCloseClick(CloseClientEvent event) {
                dc.destroy();
            }
        });
        dc.show();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
